<?php
/**
 * $Id: brazilianids_cck.inc,v 1.1.1.1 2007/12/10 16:45:06 brmassa Exp $
 * @file brazilianids_cck.inc
 * Deal with brazilian IDs like CPF and CNPJ as CCK fields.
 */

/**
 * Implementation of hook_field().
 */
function brazilianids_field($op, &$node, $field, &$node_field, $teaser, $page) {
  switch ($op) {
    case 'view':
      foreach ($node_field as $delta => $item) {
        $node_field[$delta]['view'] = content_format($field, $item, 'default', $node);
      }
      return theme('field', $node, $field, $node_field, $teaser, $page);
  }
}

/**
 *Implementation of hook_field_formatter_info
 *
 */
function brazilianids_field_formatter_info() {
  return array(
    'default' => array(
      'label'       => 'Default',
      'field types' => array('brazilianids_cpf', 'brazilianids_cnpj', 'brazilianids_cpfcnpj'),
    ),
  );
}

/**
  *Implementation of hook_field_formatter
  */
function brazilianids_field_formatter($field, $item, $formatter, $node) {
  if (!isset($item['value'])) {
    return '';
  }
  if ($field['text_processing']) {
    $text = check_markup($item['value'], $item['format'],
      is_null($node) or isset($node->in_preview));
  }
  else {
    $text = check_plain($item['value']);
  }

  return $text;
}

/**
 * Implementation of hook_field_info().
 */
function brazilianids_field_info() {
  return array(
    'brazilianids_cpf'     => array('label' => t('CPF')),
    'brazilianids_cnpj'    => array('label' => t('CNPJ')),
    'brazilianids_cpfcnpj' => array('label' => t('CPF/CNPJ')),
  );
}

/**
 * Implementation of hook_widget().
 */
function brazilianids_widget($op, &$node, $field, &$node_field) {
  switch ($op) {
    case 'form':
      $form = array();
      $form[$field['field_name']] = array('#tree' => TRUE);

      if ($field['multiple']) {
        $form[$field['field_name']]['#type'] = 'fieldset';
        $form[$field['field_name']]['#title'] = t($field['widget']['label']);
        foreach (range(0, 2) as $delta) {
          $form[$field['field_name']][$delta]['value'] = array(
            '#type'          => 'textfield',
            '#title'         => '',
            '#default_value' => isset($node_field[$delta]['value']) ? $node_field[$delta]['value'] : '',
            '#required'      => $field['required'] ? $field['required'] : FALSE,
            '#maxlength'     => 14,
            '#weight'        => $field['widget']['weight'],
            '#size'          => isset($field['widget']['size']) ? $field['widget']['size'] : 14,
            '#description'   => $field['widget']['description'],
          );
        }
      }
      else {
        $fieldsize =  $field['type'] == 'brazilianids_cpf' ? 14 : 18;
        $form[$field['field_name']][0]['value'] = array(
          '#type'          => 'textfield',
          '#title'         => $field['widget']['label'],
          '#default_value' => isset($node_field[0]['value']) ? $node_field[0]['value'] : '',
          '#required'      => $field['required'] ? $field['required'] : FALSE,
          '#maxlength'     => $fieldsize,
          '#weight'        => $field['widget']['weight'],
          '#size'          => isset($field['widget']['size']) ? $field['widget']['size'] : $fieldsize,
          '#description'   => $field['widget']['description'],
        );
      }

      return $form;

    case 'process form values':
        if (is_array($node_field)) {
          foreach ($node_field as $delta => $item) {
          //format the cpf and cnpj
          if ($item['value'] != '') {
            if ($field['type'] == 'brazilianids_cpf') {
              $node_field[0]['value'] = brazilianids_format_cpf($node_field[0]['value']);
            }
            if ($field['type'] == 'brazilianids_cnpj') {
              $node_field[0]['value'] = brazilianids_format_cnpj($node_field[0]['value']);
            }
            if ($field['type'] == 'brazilianids_cpfcnpj') {
              $node_field[0]['value'] = brazilianids_format_cpfcnpj($node_field[0]['value']);
            }
          }
        }
      }
      break;

    case 'validate':
      if (is_array($node_field)) {
        foreach ($node_field as $delta => $item) {
          if ($item['value'] != '') {
            if ($field['type'] == 'brazilianids_cpf' && !brazilianids_validate_cpf($item['value'])) {
              form_set_error($field['field_name'], t('"%value" is not a valid CPF', array('%value' => $item['value'])));
            }
            if ($field['type'] == 'brazilianids_cnpj' && !brazilianids_validate_cnpj($item['value'])) {
              form_set_error($field['field_name'], t('"%value" is not a valid CNPJ', array('%value' => $item['value'])));
            }
            if ($field['type'] == 'brazilianids_cpfcnpj' && !brazilianids_validate_cpfcnpj($item['value'])) {
              form_set_error($field['field_name'], t('"%value" is not a valid CPF/CNPJ', array('%value' => $item['value'])));
            }
          }
        }
      }
      break;
  }
}

/**
 * Implementation of hook_widget_info().
 */
function brazilianids_widget_info() {
  return array(
    'brazilianids_cpf_cnpj'      => array(
      'label'       => t('Textfield'),
      'field types' => array('brazilianids_cpf', 'brazilianids_cnpj', 'brazilianids_cpfcnpj'),
    ),
  );
}
